﻿#include <stdio.h>

#ifdef  WIN32
#define WIN32_LEAN_AND_MEAN		// 从 Windows 头中排除极少使用的资料
// Windows 头文件:
#include <windows.h>
#endif
#include "d3d9types.h"
typedef int (CALLBACK * PaintCallback)(LONG context, HWND hWnd, HDC hDC, LONG lwidth, long lHeight);

#ifndef ONVIF_EASY_VVCONVIFCALLBACK
#define ONVIF_EASY_VVCONVIFCALLBACK
/**
	消息交互回调
 
    @param context		回调上下文
	@param handle		回调相关句柄
	@param id			回调消息编号，见 CB_RES_XXXXX系列宏
	@param tag1		
    @param tag2			函数调用结果
	@param info			回调消息内容
	@param info_len		回调消息内容长度

*/
typedef int (CALLBACK * vv_cli_callback)(long context, long handle, int id, int tag1, int tag2, const char *info, int info_len);
#endif

//交互回掉命令定义
#define CB_CLI_SERCHDEV_RES						0x0001	//搜索局域网内的设备
#define CB_CLI_P2P_CONNECTED					0x0100	//p2p连接结果
#define CB_CLI_P2P_MAPPED						0x00ff	//p2p端口映射结果
#define CB_CLI_PLAY_PROCESS						0x0101	//rtsp打开播放过程的进度

#define CB_CLI_DOWNLOAD_FIRMWARE_PROCESS		0x0102	//下载固件升级文件进度
#define CB_CLI_DOWNLOAD_FIRMWARE_RESULT			0x0103	//下载固件升级文件结果
#define CB_CLI_UPGRADE_FIRMWARE_PROCESS			0x0104	//升级固件进度
#define CB_CLI_UPGRADE_FIRMWARE_RESULT			0x0105	//升级固件结果
#define CB_CLI_FORMAT_SDCARD_RESULT				0x0106  //格式化sd卡进度


#define CB_CLI_PLAY_RES							0x30000	//预览结果返回
/**
handle: play handle
tag2: 0=rtsp 预览结果返回  1=私有协议预览返回
调用vv_cli_start_play tag1：
  = 0 成功
-1=客户端句柄不存在
-2=库未初始化
-3=rtsp播放句柄不存在
-4=连接失败
-5=rtsp describe失败
-6=rtsp setup失败
-7=rtsp play失败
-8=超时 
调用vv_cli_start_play_channel tag1：
  = 0 成功
-1=创建连接失败
-2=p2p连接失败
-3=发送请求失败
-4=中断
-5=接收回复失败
-6=超时
-7=接收到错误的回复
203=非法请求
204=设备还未就绪
404=设备无法开启媒体流
500=请求参数错误
 */
#define CB_CLI_TALK_RES							0x30001	//对讲结果返回
/**
开启远程对讲（针对voicetalk_type == 2（私有协议）的设备
handle: play handle
tag1:
	 0=成功
	 -1=客户端句柄不存在
	 -2=库未初始化
	 -3=连接句柄不存在
	 -4=发送数据失败self->recv_buffer_left == 0
	 -5=对讲已开启，不能重复开启
	 -6=创建音频编码器失败
	 -7=创建音频解码器失败
	 -8=中断
	 -9=超时
	 -10=数据错误
	 -20=设备端对讲插件不存在
	 -21=设备端对讲插件打开失败
	 -22=开启对讲失败，可能已被别人占用
	 414=认证失败
	 500=协议格式错误
 */
#define CB_CLI_GET_DEVINFO_RES					0x30002	//获取设备信息结果返回
/*
 * 远程获取设备信息
 handle: vv_cli_create 返回的句柄
 tag1：
  0=成功							
 -1=客户端句柄不存在				
 -2=库未初始化						
 -3=连接句柄不存在
 -4=发送数据失败
 -5=接收回复失败
 -6=接收回复超时
 200=成功
 203-系统内部通信无权限
 204-设备尚未被初始化
 408-时间戳错误
 413=设备onvif服务无法访问
 414=设备账号密码错误
 500-请求包格式错误
 501-系统内部错误
 502-设备无法访问服务器或访问服务器错误
info:
tag1 == 0 : info = json格式的设备信息
tag1 != 0 : info  =p2pid

 */
#define CB_CLI_BIND_RES							0x30003	//设备绑定到用户返回
/**
 * 添加设备到云用户
 handle: vv_cli_create 返回的句柄
 tag1：
 0 = 成功
 -1=客户端句柄不存在
 -2=库未初始化
 -3=连接句柄不存在
 -4=发送数据失败
 -5=接收回复失败
 -6=接收回复超时
 -7=接收到的回复格式有误
  202-正在进行中，请等待
 203-系统内部通信无权限
 400-数据错误
 404-系统内部资源访问错误
 407-设备没有被授权
 410-绑定账号权限认证失败
 412-绑定的用户不存在
 413-设备无法访问
 414-设备账号密码错
 500-请求包格式错误
 501-系统内部错误
 502-设备与服务器交互失败
 504-无法访问根服务器

 info:p2pid
*/

#define CB_CLI_GET_PLAYBACK_CAPS_RES			0x30004	//获取设备回放属性
#define CB_CLI_GET_PLAYBACK_DATELIST_RES		0x30005	//获取设备回放属性
#define CB_CLI_GET_PLAYBACK_MINLIST_RES			0x30006	//获取设备回放属性
#define CB_CLI_PLAYBACK_RES						0x30007	//获取设备回放属性
#define CB_CLI_PLAY_VIDEO_STREAM_RES			0x30008	//预览数据返回
#define CB_CLI_PLAY_AUDIO_STREAM_RES			0x30009	//预览结果返回
#define CB_CLI_PLAYBACK_VIDEO_STREAM_RES		0x3000A	//预览数据返回
#define CB_CLI_PLAYBACK_AUDIO_STREAM_RES		0x3000B	//预览结果返回
#define CB_CLI_SENSOR_MATCH_RES					0x3000C
#define CB_CLI_SENSOR_GET_LIST_RES				0x3000D
#define CB_CLI_SENSOR_REMOVE_RES				0x3000E
#define CB_CLI_SET_SENSOR_INFO_RES				0x30010
#define CB_CLI_OPEN_DATA_CHANNEL_RES			0x30011
#define CB_CLI_SET_DEVICE_PASS_RES				0x30012
#define CB_CLI_SET_SENSOR_SUB_CHANNEL_INFO_RES	0x30013
#define CB_CLI_SET_SENSOR_REMOTE_CONTROL_SWITCH_RES	0x30014
#define CB_CLI_PLAYBACK_DATA_RES				0x30015	//回放数据缓存百分比

#define CB_CLI_SET_VEDIO_IMAGE_PARAMS_RES				0x30020
#define CB_CLI_GET_VEDIO_IMAGE_PARAMS_RES				0x30021
#define CB_CLI_SET_RECORD_SHEDULE_RES					0x30022
#define CB_CLI_GET_RECORD_SHEDULE_RES					0x30023
#define CB_CLI_SET_ALARM_SHEDULE_RES					0x30024
#define CB_CLI_GET_ALARM_SHEDULE_RES					0x30025
#define CB_CLI_GET_SDCARD_INFO_RES						0x30026
#define CB_CLI_FORMAT_SDCARD_INFO_RES					0x30027
#define CB_CLI_UPGRADE_FIREWARE_RES						0x30028
#define CB_CLI_GET_EVENT_LOG_RES						0x30029
#define CB_CLI_GET_EVENT_PIC_RES						0x3002A
#define CB_CLI_NETIF_SETTING_RES						0x3002B
#define CB_CLI_REBOOT_DEVICE_RES						0x3002C
#define CB_CLI_SCAN_WIFI_RES							0x3002D
#define CB_CLI_CONNECT_TO_DEVICE_RES					0x3002E
#define CB_CLI_GET_NETSETTING_RES						0x3002F
#define CB_CLI_SET_VEDIO_IMAGE_MIRROR_RES				0x30030
#define CB_CLI_GET_VEDIO_IMAGE_MIRROR_RES				0x30031
#define CB_CLI_CUSTOMER_CMD_RES							0x30032
#define CB_CLI_CONVEERT_TO_AVI							0x30033


#define CB_RENDER_BASE				(0x2000)
#define CB_VIDEO_STREAM_GOT			(CB_RENDER_BASE + 0x03)		//获取到媒体流
#define CB_VIDEO_RENDER_RES			(CB_RENDER_BASE + 0x04)		//媒体格式信息错误
#define CB_AUDIO_RENDER_RES			(CB_RENDER_BASE + 0x05)		//初始化播放器Render失败
#define CB_VOICE_CAPTURER_RES		(CB_RENDER_BASE + 0x06)		//播放时，码率，丢包率等信息
#define CB_PIC_CAPTURED				(CB_RENDER_BASE + 0x07)		//截图已截好
#define CB_VIDEO_STREAM_LONGTIME_NOTGOT	(CB_RENDER_BASE + 0x08)	//长时间未获取媒体流

#define CB_OK								0
#define CB_ERROR_BUILD_MSG					-2
#define CB_ERROR_POST_FAIL					-3
#define CB_ERROR_SERVER_MSG_BACK_FAIL		-4
#define CB_ERROR_HAVENOT_ACCESS_URL			-5
#define CB_UNINIT							-6

#define CB_ERROR_CONNECT					0xFF00  //	0:未连通
//	0xFF01:		不存在
//	0xFF02:		P2P连接失败，等待30秒后自动重连
//	0xFF03:		P2P连接中断，等待30秒后自动重连
//	0xFF04:		对方离线，等待30秒后自动重连
//	0xFF05:		设备有密码，密码认证失败
//	0xFF06:		连接句柄不存在

//===========传感器类型======================
#define VV_SENSOR_DOOR			0x01		//门磁
#define VV_SENSOR_IR			0x02		//红外
#define VV_SENSOR_SMOG			0x03		//烟感
#define VV_SENSOR_GAS			0x04		//煤气
#define VV_SENSOR_WATER			0x05		//水浸
#define VV_SENSOR_SNAKE			0x06		//振动
#define VV_SENSOR_RCTRL			0x07		//遥控器
#define VV_SENSOR_IR_CURTAIN	0xB//0x08		//幕帘
#define VV_SENSOR_SWITCH		0xF1		//开关
#define VV_SENSOR_PLUG_SEAT		0xF2		//插座
#define VV_SENSOR_WIN_CURTAIN	0xF9		//遥控窗帘



//PTZ Control CMD
#define PTZ_STOP		0	//停止
#define PTZ_UP			1	//上转
#define PTZ_DOWN		2	//下转
#define PTZ_LEFT		3	//左转
#define PTZ_RIGHT		4	//右转
#define PTZ_ZOOM_IN		5	//拉近
#define PTZ_ZOOM_OUT	6	//拉远
#if 0
#ifndef TVIDEOPARAMS
#define TVIDEOPARAMS
typedef struct _TVideoParams
{
	int timestamp;
	int width;
	int height;
	int frame_rate;
	int stream_format;
	int frame_type;
	unsigned char *data0;
	int linesize0;
	unsigned char *data1;
	int linesize1;
	unsigned char *data2;
	int linesize2;
	int datetime;
} TVideoParams;
#endif

#ifndef TAUDIOPARAMS
#define TAUDIOPARAMS
typedef struct _TAudioParams
{
	int timestamp;
	int sample_rate;
	int bit_rate;
	int channels;
	int stream_format;
	unsigned char *data;
	int len;
	int buffsize;
}TAudioParams;
#endif


/**
 视频流参数
 */
#ifndef TSTREAMPARAMS
#define TSTREAMPARAMS
typedef struct _TStreamParams
{
    /**编码格式， 1＝h.264 2=mpeg4 3=mjpeg*/
	int video_codec_type;
    /**视频宽度*/
	int width;
    /**视频高度*/
	int height;
    /**视频帧率*/
	int frame_rate;
    /**视频码率*/
	int bit_rate;

	int audio_codec_type;
	int sample_rate;
	int audio_bit_rate;
	int channels;
}TStreamParams;
#endif
#endif


#define DEVICE_TYPE_COMMONE				0
#define DEVICE_TYPE_FISHEYE				1

void WINAPI vv_cli_enable_p2p(int enable_p2p);
long WINAPI	vv_cli_init();
long WINAPI vv_cli_init_v2(char *svr_addr, unsigned short svr_port, char *key);
void WINAPI	vv_cli_uninit();
long WINAPI	vv_cli_setcallback(vv_cli_callback callback, long context);
void WINAPI	vv_cli_detach_callback();
void WINAPI	vv_cli_start_search_device();
void WINAPI	vv_cli_stop_search_device();
int WINAPI vv_cli_is_searching_device();
BOOL WINAPI vv_cli_connect_ip_state(long clihandle);


long WINAPI	vv_cli_create(const char* p2pid, const char* ip, unsigned int port, const char* user, const char* pass);
void WINAPI	vv_cli_set_device_type(long clihandle, int device_type);
long WINAPI	vv_cli_create_ex(const char* p2pid, const char* ip, unsigned int port, const char* user, const char* pass, int device_type);
void WINAPI	vv_cli_release(long clihandle);

long WINAPI	vv_cli_start_play(long clihandle, HWND hWnd, const char *url);
void WINAPI vv_cli_stop_play(long clihandle, long play_handle);

long WINAPI	vv_cli_start_play_channel(long clihandle, HWND hWnd, int channel, int stream);
int  WINAPI vv_cli_get_stream_stat(long play_handle, long long *total, int *avg, int *curr);

bool WINAPI	vv_cli_audio_exists(long play_handle);
int	 WINAPI	vv_cli_set_audio_state(long play_handle, bool bState);
int	 WINAPI	vv_cli_isrecording(long play_handle);
int	 WINAPI	vv_cli_start_record(long play_handle, int frame_rate, char* record_path);
int	 WINAPI	vv_cli_stop_record(long play_handle);

int WINAPI vv_cli_start_record_ex(long play_handle, char* record_path, char *rec_snapshot_filename, int max_sec);
int WINAPI vv_cli_stop_record_ex(long play_handle);
int WINAPI vv_cli_isrecording_ex(long play_handle);

long WINAPI	vv_cli_set_talk_state(long play_handle, bool bState);
void WINAPI	vv_cli_capture(long play_handle, char* pic_path);
void WINAPI	vv_cli_set_volume(long play_handle, long volume); 
long WINAPI	vv_cli_get_volume(long play_handle); 
void WINAPI	vv_cli_set_osd(long play_handle,  char* osd, int pos, int x, int y); 
void WINAPI	vv_cli_showvideo(long play_handle,  int x, int y, int cx, int cy); 
void WINAPI	vv_cli_showvideo_normal(long play_handle);

void WINAPI vv_cli_rectangle(long play_handle,CONST RECT* pRect, D3DCOLOR Color);
int  WINAPI vv_cli_ptz_control(long play_handle, int channel, int stream, int cmd, int param1, int param2);

int	 WINAPI	vv_cli_start_talk(long clihandle, long play_handle, int channel, int voicetalk_type);
int  WINAPI vv_cli_stop_talk(long clihandle, long play_handle);

int	 WINAPI vv_cli_playback_get_cap(long clihandle);
int  WINAPI vv_cli_playback_get_year_list(long clihandle,int chl_id, int rec_type, int year);
int  WINAPI vv_cli_playback_get_date_list(long clihandle,int chl_id, int rec_type, int year, int month);
int  WINAPI vv_cli_playback_get_min_list(long clihandle, int chl_id, int rec_type, int year, int month, int day);

long WINAPI vv_cli_replayer_start_bytime(long clihandle, HWND hWnd, int chl_id, char *time);
long WINAPI vv_cli_replayer_stop(long replay_handle);
time_t  WINAPI  vv_cli_replayer_get_video_utctime(long replay_handle);
int	 WINAPI	vv_cli_replayer_set_audio_state(long replay_handle, bool bState);
void WINAPI	vv_cli_replayer_set_volume(long replay_handle, long volume); 
long WINAPI	vv_cli_replayer_get_volume(long replay_handle); 
void WINAPI	vv_cli_replayer_osd(long replay_handle,  char* osd, int pos, int x, int y); 

long WINAPI vv_cli_rec_play(HWND hWnd, char *filename);
long WINAPI vv_cli_rec_play_ex(HWND hWnd, int device_type, char *filename);
int  WINAPI vv_cli_rec_stop(long replay_handle);
long WINAPI vv_cli_rec_play_control(long replay_handle, int control_type/*1-正常播放 2-暂停*/);
long WINAPI vv_cli_rec_play_speed(long replay_handle, int play_speed/*1-正常 2-2倍速  4-4倍速 8-8倍速 16-16倍速*/);
void WINAPI	vv_cli_rec_osd(long replay_handle,  char* osd, int pos, int x, int y);
long WINAPI vv_cli_rec_covert_to_avi(char *filename, char *avi_filename);
int  WINAPI vv_cli_rec_stop_convert(long replay_handle);


long WINAPI	vv_cli_rec_seek(long replay_handle, int time_pos);
time_t  WINAPI  vv_cli_rec_get_video_utctime(long replay_handle);
time_t  WINAPI  vv_cli_rec_get_video_total_time(long replay_handle);
time_t  WINAPI  vv_cli_rec_get_video_cur_time(long replay_handle);
int	 WINAPI	vv_cli_rec_set_audio_state(long replay_handle, bool bState);
void WINAPI	vv_cli_rec_set_volume(long replay_handle, long volume); 
long WINAPI	vv_cli_rec_get_volume(long replay_handle); 
time_t  WINAPI  vv_cli_rec_get_video_total_time(long replay_handle);
time_t  WINAPI  vv_cli_rec_get_video_cur_time(long replay_handle);


int WINAPI vv_cli_get_image_params(long play_handle);
int  WINAPI  vv_cli_get_image_params_v2(long play_handle,  char** out_json);
int WINAPI vv_cli_set_image_params(long play_handle, int brightness, int contrast, int saturation, int color_temp);

int WINAPI vv_cli_get_image_mirror(long play_handle);
int WINAPI vv_cli_set_image_mirror(long play_handle, int mirror_mode);

//异步单线程模式
int	 WINAPI	vv_cli_get_deviceinfo(long clihandle);
long WINAPI	vv_cli_bind(long clihandle, char* dev_name, char* url, char* cli_user, char* cli_pass);

int WINAPI vv_cli_rectrl_get_schedule(long clihandle, int chl_id);
int WINAPI vv_cli_rectrl_set_schedule(long clihandle, int chl_id, char *schedule_json);

int WINAPI vv_cli_set_arm_config(long clihandle, int chl_id, char *config_json);
int WINAPI vv_cli_get_arm_config(long clihandle, int chl_id);

int WINAPI vv_cli_get_sdcard_info(long clihandle);
int WINAPI vv_cli_format_sdcard(long clihandle);

int WINAPI vv_cli_upgrade_firmware(long clihandle, char *url, char *hash);
int WINAPI vv_cli_get_event_log(long clihandle, int chl_id, int arm_enabled);
int WINAPI vv_cli_get_event_pic(long clihandle, int arm_enabled, char *event_id, int index);

int WINAPI vv_cli_scan_wifi_list(long clihandle);
long WINAPI vv_cli_get_netif_settings(long clihandle);
int WINAPI  vv_cli_set_netif_settings(long clihandle, char *netif_settings_json);

int  WINAPI vv_cli_ext_sensor_match(long clihandle, int chl_id);
int  WINAPI vv_cli_stop_ext_sensor_match(long clihandle, int chl_id);

int  WINAPI vv_cli_sensor_get_list(long clihandle, int chl_id, int sensor_type);
int  WINAPI vv_cli_ext_sensor_remove(long clihandle, int chl_id, char *sensor_id);
int	 WINAPI vv_cli_ext_sensor_set_info(long clihandle, int chl_id, char *sensor_id, char *name, int preset, int is_alarm);
int	 WINAPI vv_cli_ext_sensor_set_sub_chl_info(long clihandle, int chl_id, char *sensor_id, int sub_chl_id, char *name, int alarm_linkage);
int  WINAPI vv_cli_ext_sensor_remote_control_switch(long clihandle, int chl_id, char *sensor_id, int sub_chl_id, int status);

int  WINAPI vv_cli_reboot(long clihandle);
int  WINAPI vv_cli_set_device_pass(long clihandle, char *dev_user, char *dev_pass, char *new_dev_pass);

//异步多线程自销毁模式
long  WINAPI vv_cli_get_deviceinfo_mt(long clihandle);
long  WINAPI vv_cli_bind_mt(long clihandle, char* dev_name, char* url, char* cli_user, char* cli_pass);

long  WINAPI vv_cli_get_netif_settings_mt(long clihandle);
int	  WINAPI vv_cli_set_netif_settings_mt(long clihandle, char *netif_settings_json);

int   WINAPI vv_cli_get_arm_config_mt(long clihandle, int chl_id);
int   WINAPI vv_cli_set_arm_config_mt(long clihandle, int chl_id, char *config_json);

int	  WINAPI vv_cli_rectrl_get_schedule_mt(long clihandle, int chl_id);
int   WINAPI vv_cli_rectrl_set_schedule_mt(long clihandle, int chl_id, char *schedule_json);

long  WINAPI vv_cli_scan_wifi_list_mt(long clihandle);

long  WINAPI vv_cli_ext_sensor_match_mt(long clihandle, int chl_id);
int   WINAPI vv_cli_sensor_get_list_mt(long clihandle, int chl_id, int sensor_type);

int   WINAPI vv_cli_ext_sensor_remove_mt(long clihandle, int chl_id, char *sensor_id);
int	  WINAPI vv_cli_ext_sensor_set_info_mt(long clihandle, int chl_id, char *sensor_id, char *name, int preset, int is_alarm);
int	  WINAPI vv_cli_ext_sensor_set_sub_chl_info_mt(long clihandle, int chl_id, char *sensor_id, int sub_chl_id, char *name, int alarm_linkage);
int   WINAPI vv_cli_ext_sensor_remote_control_switch_mt(long clihandle, int chl_id, char *sensor_id, int sub_chl_id, int status);

int   WINAPI vv_cli_get_sdcard_info_mt(long clihandle);

int   WINAPI vv_cli_get_event_log_mt(long clihandle, int chl_id, int arm_enabled);
int   WINAPI vv_cli_get_event_picture_mt(long clihandle,  int arm_enabled, char *event_id, int index);

int	  WINAPI vv_cli_customer_cmd_mt(long clihandle, char *buffer, int size);

//同步模式
long WINAPI  vv_cli_connect(long clihandle);
void WINAPI	 vv_cli_disconnect(long connect_handle);
void WINAPI	 vv_cli_free(char* data);
int	 WINAPI	 vv_cli_get_deviceinfo_sync(long connect_handle, char** out_json, int need_callback);
int  WINAPI  vv_cli_reboot_sync(long connect_handle, int need_callback);
int  WINAPI  vv_cli_set_device_pass_sync(long connect_handle, char *dev_user, char *dev_pass, char *new_dev_pass, int need_callback);
int  WINAPI  vv_cli_get_image_params_sync(long connect_handle, int channel,  char** out_json, int need_callback);

int  WINAPI  vv_cli_set_image_params_sync(long connect_handle, int channel, int brightness, int contrast, int saturation, int color_temp, int need_callback);
int  WINAPI  vv_cli_get_image_mirror_sync(long connect_handle, int channel, int* mirror_mode, int need_callback);
int  WINAPI  vv_cli_set_image_mirror_sync(long connect_handle, int channel,  int mirror_mode, int need_callback);

int  WINAPI  vv_cli_rectrl_get_schedule_sync(long connect_handle, int chl_id, char** schedule_json, int need_callback);
int  WINAPI  vv_cli_rectrl_set_schedule_sync(long connect_handle, int chl_id, char *schedule_json, int need_callback);

int  WINAPI  vv_cli_set_arm_config_sync(long connect_handle, int chl_id, char *config_json, int need_callback);
int  WINAPI  vv_cli_get_arm_config_sync(long connect_handle, int chl_id, char** out_json, int need_callback);

int  WINAPI  vv_cli_get_sdcard_info_sync(long connect_handle, char** out_json, int need_callback);
int  WINAPI  vv_cli_format_sdcard_sync(long connect_handle, int need_callback);

int  WINAPI  vv_cli_upgrade_firmware_sync(long connect_handle, char *url, char *hash, int need_callback);

int  WINAPI  vv_cli_get_event_log_sync(long connect_handle, int chl_id, int arm_enabled, char** out_json, int need_callback);
int  WINAPI  vv_cli_get_event_pic_sync(long connect_handle, int arm_enabled, char *event_id, int index, char* buffer, int buffer_size, int* size, int need_callback);

int  WINAPI vv_cli_scan_wifi_list_sync(long connect_handle, char** out_json, int need_callback);

long WINAPI vv_cli_get_netif_settings_sync(long connect_handle, char** out_json, int need_callback);
int  WINAPI vv_cli_set_netif_settings_sync(long connect_handle, char *netif_settings_json, int need_callback);

int  WINAPI vv_cli_ext_sensor_match_sync(long connect_handle, int chl_id, char** out_json, int need_callback);
int  WINAPI vv_cli_sensor_get_list_sync(long connect_handle, int chl_id, int sensor_type, char** out_json, int need_callback);
int  WINAPI vv_cli_ext_sensor_remove_sync(long connect_handle, int chl_id, char *sensor_id, int need_callback);
int	 WINAPI vv_cli_ext_sensor_set_info_sync(long connect_handle, int chl_id, char *sensor_id, char *name, int preset, int is_alarm, int need_callback);
int	 WINAPI vv_cli_ext_sensor_set_sub_chl_info_sync(long connect_handle, int chl_id, char *sensor_id, int sub_chl_id, char *name, int alarm_linkage, int need_callback);
int  WINAPI vv_cli_ext_sensor_remote_control_switch_sync(long connect_handle, int chl_id, char *sensor_id, int sub_chl_id, int status, int need_callback);



int  WINAPI vv_cli_wifi_start_config(char *ssid, char *passwd);
void WINAPI vv_cli_wifi_stop_config();

int  WINAPI vv_cli_trchl_open(long clihandle);
int	 WINAPI vv_cli_trchl_close(long clihandle);
int  WINAPI vv_cli_trchl_send(long clihandle, char *buffer, int size);

long  WINAPI vv_cli_user_open(long clihandle, int port, char *p2p_dev_pass);
int	 WINAPI vv_cli_user_close(long clihandle, long connect_handle);
int  WINAPI vv_cli_user_send(long connect_handle, char *buffer, int size);

void WINAPI vv_cli_scaling(long play_handle, int state, float scaling);
void WINAPI vv_cli_change_angle(long play_handle, int state, int nAngle);
void WINAPI vv_cli_move_looking(long play_handle, int state, int nStep);